# -*- coding: utf-8 -*-
"""
Package gathering all unitary tests for pythonnest.
Module names must start with `test_` to be taken into account.

You should consider to install :mod:`Distribute` to run all tests with::

    $ python setup.py test

"""
import unittest
__author__ = 'Matthieu Gallet'
# __copyright__ = "Copyright 2013, 19pouces.net"
# __credits__ = "flanker"
# __maintainer__ = "flanker"
# __email__ = "flanker@19pouces.net"

if __name__ == '__main__':
    unittest.main()